==> deepin-update-ui_1.0.6.tar.xz: BUILD/src/dcc-update-plugin/translations/update_fi.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fi">
<context>
    <name>CheckUpdate</name>
    <message>
        <source>Last check: </source>
        <translation>Tarkistettu: </translation>
    </message>
</context>
<context>
    <name>NoActive</name>
    <message>
        <source>Your system is not activated, and it failed to connect to update services</source>
        <translation>Tietokonetta ei ole aktivoitu, eikä se onnistu saamaan yhteyttä päivityspalveluihin.</translation>
    </message>
</context>
<context>
    <name>QuitTestingChannelDialog</name>
    <message>
        <source>If you exit the beta program, you will no longer receive beta updates.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateHistoryDialog</name>
    <message>
        <source>Exit</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateHistoryDialog</name>
    <message>
        <source>Save the display settings?</source>
        <translation>Tallennatko näytön asetukset?</translation>
    </message>
    <message>
        <source>Settings will be reverted in %1s.</source>
        <translation>Asetukset palautetaan %1s kulttua.</translation>
    </message>
    <message>
        <source>Revert</source>
        <translation>Palauta</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Tallenna</translation>
    </message>
</context>
<context>
    <name>UpdateList</name>
    <message>
        <source>View Details</source>
        <translation>Näytä tiedot</translation>
    </message>
    <message>
        <source>Updates:</source>
        <translation>Päivitykset:</translation>
    </message>
    <message>
        <source>Release time:</source>
        <translation>Julkaisupäivä:</translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation>Tiivistetty</translation>
    </message>
</context>
<context>
    <name>UpdateLogHelper</name>
    <message>
        <source>NONE</source>
        <translation>EI MITÄÄN</translation>
    </message>
    <message>
        <source>LOW</source>
        <translation>MATALA</translation>
    </message>
    <message>
        <source>MEDIUM</source>
        <translation>KESKITASO</translation>
    </message>
    <message>
        <source>HIGH</source>
        <translation>KORKEA</translation>
    </message>
    <message>
        <source>CRITICAL</source>
        <translation>KRIITTINEN</translation>
    </message>
    <message>
        <source>critical-risk</source>
        <translation>kriittinen riski</translation>
    </message>
    <message>
        <source>high-risk</source>
        <translation>suuri riski</translation>
    </message>
    <message>
        <source>medium-risk</source>
        <translation>keskitason riski</translation>
    </message>
    <message>
        <source>low-risk</source>
        <translation>matala riski</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>tuntematon</translation>
    </message>
    <message>
        <source>This update fixes</source>
        <translation>Päivitys korjaa</translation>
    </message>
    <message>
        <source>vulnerabilities</source>
        <translation>haavoittuvuuksia</translation>
    </message>
    <message>
        <source>vulnerability</source>
        <translation>haavoittuvuuden</translation>
    </message>
    <message>
        <source>%1 of %2 %3</source>
        <translation>%1 - %2 %3</translation>
        <extra-content_explain>`数字+%`会在代码中替换为字符串，例如：3 of high-risk vulnerabilities；各语言需要根据实际情况增加空格(例如：中文没有空格，英文有空格)</extra-content_explain>
    </message>
    <message>
        <source>, </source>
        <translation>, </translation>
        <extra-content_explain>中文逗号不需要空格，英文逗号需要空格For more details, please visit</extra-content_explain>
    </message>
    <message>
        <source>for more details, please visit </source>
        <translation>lisätietoja osoitteessa</translation>
        <extra-content_explain>这句话后面会带上一个超链接，各语言自行决定末尾需不需要加空格</extra-content_explain>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Checking for updates, please wait…</source>
        <translation>Tarkistetaan päivityksiä, odota...</translation>
    </message>
    <message>
        <source>Your system is up to date</source>
        <translation>Tietokone on päivitetty</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Tuntematon virhe</translation>
    </message>
    <message>
        <source>Downloading updates failed. Please free up %1 disk space first.</source>
        <translation>Päivitysten lataaminen epäonnistui. Vapauta ensin %1 levytilaa.</translation>
    </message>
    <message>
        <source>Dependency error, failed to detect the updates</source>
        <translation>Riippuvuusvirhe, päivityksiä ei havaittu</translation>
    </message>
    <message>
        <source>Please check your network and try again.</source>
        <translation>Tarkista lähiverkko ja yritä uudelleen.</translation>
    </message>
    <message>
        <source>Downloading updates failed. Please check your network and try again.</source>
        <translation>Päivitysten lataaminen epäonnistui. Tarkista lähiverkko ja yritä uudelleen.</translation>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>Järjestelmän varmuuskopio ei onnistunut. Jos jatkat päivityksiä, et voi palata takaisin vanhaan järjestelmään.</translation>
    </message>
    <message>
        <source>If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>Jos jatkat päivityksiä, et voi palata takaisin vanhaan järjestelmään.</translation>
    </message>
    <message>
        <source>Insufficient disk space</source>
        <translation>Liian vähän levytilaa</translation>
    </message>
    <message>
        <source>DPKG error</source>
        <translation>DPKG virhe</translation>
    </message>
    <message>
        <source>File missing</source>
        <translation>Tiedosto puuttuu</translation>
    </message>
    <message>
        <source>Service connection is abnormal, please check the network and try again</source>
        <translation>Palvelun yhteys ei toimi normaalisti. Tarkista verkko ja yritä uudelleen</translation>
    </message>
    <message>
        <source>The repository source configuration is not valid, please check and try again.</source>
        <translation>Arkiston lähde ei ole kelvollinen, tarkista ja yritä uudelleen.</translation>
    </message>
    <message>
        <source>Check Again</source>
        <translation>Tarkista uudelleen</translation>
    </message>
</context>
<context>
    <name>UpdateSetting</name>
    <message>
        <source>Smart Mirror Switch</source>
        <translation>Älykäs pakettivaraston vaihto</translation>
    </message>
    <message>
        <source>Update Type</source>
        <translation>Päivitys</translation>
    </message>
    <message>
        <source>Function Updates</source>
        <translation>Ominaisuuspäivitykset</translation>
    </message>
    <message>
        <source>Delivers a cumulative update including new features, quality updates, and  security updates</source>
        <translation>Kumulatiivinen päivitys, joka sisältää uusia ominaisuuksia, laatupäivityksiä ja tietoturvapäivityksiä</translation>
    </message>
    <message>
        <source>Security Updates</source>
        <translation>Tietoturvapäivitykset</translation>
    </message>
    <message>
        <source>Delivers security updates</source>
        <translation>Toimittaa tietoturvapäivityksiä</translation>
    </message>
    <message>
        <source>Third-party Updates</source>
        <translation>Kolmannen osapuolen päivitykset</translation>
    </message>
    <message>
        <source>Delivers  updates for additional repository sources</source>
        <translation>Toimittaa päivityksiä ohjelma-arkistojen lähteille</translation>
    </message>
    <message>
        <source>Limit Speed</source>
        <translation>Rajoita nopeutta</translation>
    </message>
    <message>
        <source>Limit Setting</source>
        <translation>Rajoituksen asetus</translation>
    </message>
    <message>
        <source>Auto Download</source>
        <translation>Automaattinen lataus</translation>
    </message>
    <message>
        <source>Enabling &quot;Auto Download Updates&quot; will automatically download updates when connected to the internet</source>
        <translation>Ottamalla &quot;Automaattinen lataus&quot; käyttöön se lataa päivitykset, kun Internet on muodostettu</translation>
    </message>
    <message>
        <source>Download when Inactive</source>
        <translation>Lataa ei aktiiviseen aikaan</translation>
    </message>
    <message>
        <source>Start at</source>
        <translation>Alkaen</translation>
    </message>
    <message>
        <source>End at</source>
        <translation>Päättyen</translation>
    </message>
    <message>
        <source>Advanced Settings</source>
        <translation>Lisäasetukset</translation>
    </message>
    <message>
        <source>Updates Notification</source>
        <translation>Päivitysten ilmoitus</translation>
    </message>
    <message>
        <source>Clear Package Cache</source>
        <translation>Tyhjennä pakettivälimuisti</translation>
    </message>
    <message>
        <source>Update History</source>
        <translation>Päivityshistoria</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Katsele</translation>
    </message>
    <message>
        <source>Join Internal Testing Channel</source>
        <translation>Liity testauskanavaan</translation>
    </message>
    <message>
        <source>Join the internal testing channel to get deepin latest updates</source>
        <translation>Liity testauskanavaan ja saat viimeisimmät päivitykset</translation>
    </message>
    <message>
        <source>Click here to complete the application</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Click here to complete the application</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UpdateWorker</name>
    <message>
        <source>System Updates</source>
        <translation>Tietokoneen päivitykset</translation>
    </message>
    <message>
        <source>Fixed some known bugs and security vulnerabilities</source>
        <translation>Korjattu tunnettuja bugeja ja tietoturva-aukkoja</translation>
    </message>
    <message>
        <source>Security Updates</source>
        <translation>Päivityksiä tietoturvaan</translation>
    </message>
    <message>
        <source>Third-party Repositories</source>
        <translation>Kolmannen osapuolen pakettivarastot</translation>
    </message>
</context>
<context>
    <name>update</name>
    <message>
        <source>System Update</source>
        <translation>Päivitys</translation>
    </message>
    <message>
        <source>System update and upgrade</source>
        <translation>Päivitys ja versio päivitys</translation>
    </message>
</context>
<context>
    <name>updateMain</name>
    <message>
        <source>Update Settings</source>
        <translation>Päivityksen asetukset</translation>
    </message>
    <message>
        <source>Installing</source>
        <translation>Asennetaan</translation>
    </message>
    <message>
        <source>Update download completed</source>
        <translation>Päivitykset ladattiin</translation>
    </message>
    <message>
        <source>Install updates</source>
        <translation>Asenna päivitykset</translation>
    </message>
    <message>
        <source>Update size: </source>
        <translation>Päivityksen koko:</translation>
    </message>
    <message>
        <source>Update download failed</source>
        <translation>Päivityksen lataus epäonnistui</translation>
    </message>
    <message>
        <source>Downloading updates...</source>
        <translation>Ladataan päivityksiä...</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>Ladataan</translation>
    </message>
    <message>
        <source>Configure Update settings、Security Updates、Auto Download Updates and Updates Notification</source>
        <translation>Määritä päivitysasetukset, tietoturva, automaattinen lataaminen ja ilmoitukset</translation>
    </message>
    <message>
        <source>Reboot now</source>
        <translation>Käynnistä</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Lataa</translation>
    </message>
    <message>
        <source>Installing updates...</source>
        <translation>Asentaa päivityksiä...</translation>
    </message>
    <message>
        <source>Retry</source>
        <translation>Uudelleen</translation>
    </message>
    <message>
        <source>Continue Update</source>
        <translation>Jatka päivitystä</translation>
    </message>
    <message>
        <source>Updates Available</source>
        <translation>Päivityksiä saatavilla</translation>
    </message>
    <message>
        <source>Installation update failed</source>
        <translation>Päivityksen asennus epäonnistui</translation>
    </message>
    <message>
        <source>To ensure proper functioning of your system and applications, please restart your computer after the update</source>
        <translation>Varmista sovellusten moitteeton toiminta käynnistämällä tietokone uudelleen päivityksen jälkeen</translation>
    </message>
    <message>
        <source>Backing up in progress...</source>
        <translation>Varmuuskopiointi käynnissä...</translation>
    </message>
    <message>
        <source>Backing up in progress</source>
        <translation>Varmuuskopiointi käynnissä</translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation>Varmuuskopio epäonnistui</translation>
    </message>
    <message>
        <source>Update installation successful</source>
        <translation>Päivitys asennettu</translation>
    </message>
    <message>
        <source>Back Up Again</source>
        <translation>Varmista uudelleen</translation>
    </message>
</context>
</TS>

==> deepin-update-ui_1.0.12.tar.xz: BUILD/src/dcc-update-plugin/translations/update_fi.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fi">
<context>
    <name>CheckUpdate</name>
    <message>
        <source>Last check: </source>
        <translation>Tarkistettu: </translation>
    </message>
</context>
<context>
    <name>QuitTestingChannelDialog</name>
    <message>
        <source>If you exit the beta program, you will no longer receive beta updates.</source>
        <translation>Jos poistut beta-ohjelmasta, et enää saa beta-päivityksiä.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Poistu</translation>
    </message>
</context>
<context>
    <name>UpdateDisable</name>
    <message>
        <source>The system updates are disabled. Please contact your administrator for help</source>
        <translation>Päivitykset ovat poistettu käytöstä. Pyydä apua järjestelmänvalvojaltasi.</translation>
    </message>
    <message>
        <source>Your system is not activated, and it failed to connect to update services</source>
        <translation>Tietokonetta ei ole aktivoitu, eikä se onnistu saamaan yhteyttä päivityspalveluihin.</translation>
    </message>
</context>
<context>
    <name>UpdateHistoryDialog</name>
    <message>
        <source>Update History</source>
        <translation>Päivityshistoria</translation>
    </message>
    <message>
        <source>No update history</source>
        <translation>Ei päivitys historiaa</translation>
    </message>
    <message>
        <source>System Updates</source>
        <translation>Tietokoneen päivitykset</translation>
    </message>
    <message>
        <source>Security Updates</source>
        <translation>Tietoturvapäivitykset</translation>
    </message>
    <message>
        <source>Delivers a cumulative update including new features, quality updates, and security updates</source>
        <translation>Kumulatiivinen päivitys. Sisältää uusia ominaisuuksia, laatupäivityksiä ja tietoturvapäivityksiä</translation>
    </message>
    <message>
        <source>Delivers security updates</source>
        <translation>Toimittaa tietoturvapäivityksiä</translation>
    </message>
    <message>
        <source>Installation date:</source>
        <translation>Asennuspäivä:</translation>
    </message>
</context>
<context>
    <name>UpdateList</name>
    <message>
        <source>View Details</source>
        <translation>Näytä tiedot</translation>
    </message>
    <message>
        <source>Updates:</source>
        <translation>Päivitykset:</translation>
    </message>
    <message>
        <source>Release time:</source>
        <translation>Julkaisupäivä:</translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation>Tiivistetty</translation>
    </message>
</context>
<context>
    <name>UpdateLogHelper</name>
    <message>
        <source>NONE</source>
        <translation>EI MITÄÄN</translation>
    </message>
    <message>
        <source>LOW</source>
        <translation>MATALA</translation>
    </message>
    <message>
        <source>MEDIUM</source>
        <translation>KESKITASO</translation>
    </message>
    <message>
        <source>HIGH</source>
        <translation>KORKEA</translation>
    </message>
    <message>
        <source>CRITICAL</source>
        <translation>KRIITTINEN</translation>
    </message>
    <message>
        <source>critical-risk</source>
        <translation>kriittinen riski</translation>
    </message>
    <message>
        <source>high-risk</source>
        <translation>suuri riski</translation>
    </message>
    <message>
        <source>medium-risk</source>
        <translation>keskitason riski</translation>
    </message>
    <message>
        <source>low-risk</source>
        <translation>matala riski</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>tuntematon</translation>
    </message>
    <message>
        <source>This update fixes</source>
        <translation>Päivitys korjaa</translation>
    </message>
    <message>
        <source>vulnerabilities</source>
        <translation>haavoittuvuuksia</translation>
    </message>
    <message>
        <source>vulnerability</source>
        <translation>haavoittuvuuden</translation>
    </message>
    <message>
        <source>%1 of %2 %3</source>
        <translation>%1 - %2 %3</translation>
        <extra-content_explain>`数字+%`会在代码中替换为字符串，例如：3 of high-risk vulnerabilities；各语言需要根据实际情况增加空格(例如：中文没有空格，英文有空格)</extra-content_explain>
    </message>
    <message>
        <source>, </source>
        <translation>, </translation>
        <extra-content_explain>中文逗号不需要空格，英文逗号需要空格For more details, please visit</extra-content_explain>
    </message>
    <message>
        <source>for more details, please visit </source>
        <translation>lisätietoja osoitteessa</translation>
        <extra-content_explain>这句话后面会带上一个超链接，各语言自行决定末尾需不需要加空格</extra-content_explain>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Checking for updates, please wait…</source>
        <translation>Tarkistetaan päivityksiä, odota...</translation>
    </message>
    <message>
        <source>Your system is up to date</source>
        <translation>Tietokone on päivitetty</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Tuntematon virhe</translation>
    </message>
    <message>
        <source>Downloading updates failed. Please free up %1 disk space first.</source>
        <translation>Päivitysten lataaminen epäonnistui. Vapauta ensin %1 levytilaa.</translation>
    </message>
    <message>
        <source>Dependency error, failed to detect the updates</source>
        <translation>Riippuvuusvirhe, päivityksiä ei havaittu</translation>
    </message>
    <message>
        <source>Please check your network and try again.</source>
        <translation>Tarkista lähiverkko ja yritä uudelleen.</translation>
    </message>
    <message>
        <source>Downloading updates failed. Please check your network and try again.</source>
        <translation>Päivitysten lataaminen epäonnistui. Tarkista lähiverkko ja yritä uudelleen.</translation>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>Järjestelmän varmuuskopio ei onnistunut. Jos jatkat päivityksiä, et voi palata takaisin vanhaan järjestelmään.</translation>
    </message>
    <message>
        <source>If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>Jos jatkat päivityksiä, et voi palata takaisin vanhaan järjestelmään.</translation>
    </message>
    <message>
        <source>Insufficient disk space</source>
        <translation>Liian vähän levytilaa</translation>
    </message>
    <message>
        <source>DPKG error</source>
        <translation>DPKG virhe</translation>
    </message>
    <message>
        <source>File missing</source>
        <translation>Tiedosto puuttuu</translation>
    </message>
    <message>
        <source>Service connection is abnormal, please check the network and try again</source>
        <translation>Palvelun yhteys ei toimi normaalisti. Tarkista verkko ja yritä uudelleen</translation>
    </message>
    <message>
        <source>The repository source configuration is not valid, please check and try again.</source>
        <translation>Arkiston lähde ei ole kelvollinen, tarkista ja yritä uudelleen.</translation>
    </message>
    <message>
        <source>Check Again</source>
        <translation>Tarkista uudelleen</translation>
    </message>
    <message>
        <source>Privacy Policy</source>
        <translation>Tietosuojakäytäntö</translation>
    </message>
    <message>
        <source>To use this software, you must accept the %1 that accompanies software updates.</source>
        <translation>Jotta voit käyttää tätä ohjelmistoa, sinun on hyväksyttävä ohjelmistopäivitysten mukana tuleva %1.</translation>
    </message>
    <message>
        <source>Turn on the switches under Update Content to get better experiences</source>
        <translation>Ota käyttöön &quot;Päivitä sisältö&quot; kytkimet saadaksesi paremman kokemuksen</translation>
    </message>
</context>
<context>
    <name>UpdateSetting</name>
    <message>
        <source>Smart Mirror Switch</source>
        <translation>Älykäs pakettivaraston vaihto</translation>
    </message>
    <message>
        <source>Update Type</source>
        <translation>Päivitys</translation>
    </message>
    <message>
        <source>Function Updates</source>
        <translation>Ominaisuuspäivitykset</translation>
    </message>
    <message>
        <source>Delivers a cumulative update including new features, quality updates, and  security updates</source>
        <translation>Kumulatiivinen päivitys, joka sisältää uusia ominaisuuksia, laatupäivityksiä ja tietoturvapäivityksiä</translation>
    </message>
    <message>
        <source>Security Updates</source>
        <translation>Tietoturvapäivitykset</translation>
    </message>
    <message>
        <source>Delivers security updates</source>
        <translation>Toimittaa tietoturvapäivityksiä</translation>
    </message>
    <message>
        <source>Third-party Updates</source>
        <translation>Kolmannen osapuolen päivitykset</translation>
    </message>
    <message>
        <source>Delivers  updates for additional repository sources</source>
        <translation>Toimittaa päivityksiä ohjelma-arkistojen lähteille</translation>
    </message>
    <message>
        <source>Limit Speed</source>
        <translation>Rajoita nopeutta</translation>
    </message>
    <message>
        <source>Limit Setting</source>
        <translation>Rajoituksen asetus</translation>
    </message>
    <message>
        <source>Auto Download</source>
        <translation>Automaattinen lataus</translation>
    </message>
    <message>
        <source>Enabling &quot;Auto Download Updates&quot; will automatically download updates when connected to the internet</source>
        <translation>Ottamalla &quot;Automaattinen lataus&quot; käyttöön se lataa päivitykset, kun Internet on muodostettu</translation>
    </message>
    <message>
        <source>Download when Inactive</source>
        <translation>Lataa ei aktiiviseen aikaan</translation>
    </message>
    <message>
        <source>Start at</source>
        <translation>Alkaen</translation>
    </message>
    <message>
        <source>End at</source>
        <translation>Päättyen</translation>
    </message>
    <message>
        <source>Advanced Settings</source>
        <translation>Lisäasetukset</translation>
    </message>
    <message>
        <source>Updates Notification</source>
        <translation>Päivitysten ilmoitus</translation>
    </message>
    <message>
        <source>Clear Package Cache</source>
        <translation>Tyhjennä pakettivälimuisti</translation>
    </message>
    <message>
        <source>Update History</source>
        <translation>Päivityshistoria</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Katsele</translation>
    </message>
    <message>
        <source>Join Internal Testing Channel</source>
        <translation>Liity testauskanavaan</translation>
    </message>
    <message>
        <source>Click here to complete the application</source>
        <translation>Viimeistele sovellus painamalla</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>Laajenna</translation>
    </message>
    <message>
        <source>Forum users at level 2 and above can join the beta test to receive the latest updates.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateWorker</name>
    <message>
        <source>System Updates</source>
        <translation>Tietokoneen päivitykset</translation>
    </message>
    <message>
        <source>Fixed some known bugs and security vulnerabilities</source>
        <translation>Korjattu tunnettuja bugeja ja tietoturva-aukkoja</translation>
    </message>
    <message>
        <source>Security Updates</source>
        <translation>Päivityksiä tietoturvaan</translation>
    </message>
    <message>
        <source>Third-party Repositories</source>
        <translation>Kolmannen osapuolen pakettivarastot</translation>
    </message>
</context>
<context>
    <name>update</name>
    <message>
        <source>System Update</source>
        <translation>Päivitys</translation>
    </message>
    <message>
        <source>System update and upgrade</source>
        <translation>Päivitys ja versio päivitys</translation>
    </message>
</context>
<context>
    <name>updateMain</name>
    <message>
        <source>Update Settings</source>
        <translation>Päivityksen asetukset</translation>
    </message>
    <message>
        <source>Installing</source>
        <translation>Asennetaan</translation>
    </message>
    <message>
        <source>Update download completed</source>
        <translation>Päivitykset ladattiin</translation>
    </message>
    <message>
        <source>Install updates</source>
        <translation>Asenna päivitykset</translation>
    </message>
    <message>
        <source>Update size: </source>
        <translation>Päivityksen koko:</translation>
    </message>
    <message>
        <source>Update download failed</source>
        <translation>Päivityksen lataus epäonnistui</translation>
    </message>
    <message>
        <source>Downloading updates...</source>
        <translation>Ladataan päivityksiä...</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>Ladataan</translation>
    </message>
    <message>
        <source>Configure Update settings、Security Updates、Auto Download Updates and Updates Notification</source>
        <translation>Määritä päivitysasetukset, tietoturva, automaattinen lataaminen ja ilmoitukset</translation>
    </message>
    <message>
        <source>Reboot now</source>
        <translation>Käynnistä</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Lataa</translation>
    </message>
    <message>
        <source>Installing updates...</source>
        <translation>Asentaa päivityksiä...</translation>
    </message>
    <message>
        <source>Retry</source>
        <translation>Uudelleen</translation>
    </message>
    <message>
        <source>Continue Update</source>
        <translation>Jatka päivitystä</translation>
    </message>
    <message>
        <source>Updates Available</source>
        <translation>Päivityksiä saatavilla</translation>
    </message>
    <message>
        <source>Installation update failed</source>
        <translation>Päivityksen asennus epäonnistui</translation>
    </message>
    <message>
        <source>To ensure proper functioning of your system and applications, please restart your computer after the update</source>
        <translation>Varmista sovellusten moitteeton toiminta käynnistämällä tietokone uudelleen päivityksen jälkeen</translation>
    </message>
    <message>
        <source>Backing up in progress...</source>
        <translation>Varmuuskopiointi käynnissä...</translation>
    </message>
    <message>
        <source>Backing up in progress</source>
        <translation>Varmuuskopiointi käynnissä</translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation>Varmuuskopio epäonnistui</translation>
    </message>
    <message>
        <source>Update installation successful</source>
        <translation>Päivitys asennettu</translation>
    </message>
    <message>
        <source>If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>Jos jatkat päivityksiä, et voi palata takaisin vanhaan järjestelmään.</translation>
    </message>
    <message>
        <source>Try Again</source>
        <translation>Yritä uudelleen</translation>
    </message>
    <message>
        <source>Proceed to Update</source>
        <translation>Suorita päivitys</translation>
    </message>
    <message>
        <source>The battery capacity is lower than 60%. To get successful updates, please plug in.</source>
        <translation>Akun kapasiteetti on alle 60%. Liitä kone sähköverkkoon päivityksen ajaksi.</translation>
    </message>
</context>
</TS>
